==> connectors-0.6.0-test-sources.jar: test/de/iip_ecosphere/platform/connectors/MachineData.java <==
/**
 * ******************************************************************************
 * Copyright (c) {2020} The original author or authors
 *
 * All rights reserved. This program and the accompanying materials are made 
 * available under the terms of the Eclipse Public License 2.0 which is available 
 * at http://www.eclipse.org/legal/epl-2.0, or the Apache License, Version 2.0
 * which is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * SPDX-License-Identifier: Apache-2.0 OR EPL-2.0
 ********************************************************************************/

package test.de.iip_ecosphere.platform.connectors;

/**
 * Test class representing machine data from the information model.
 * 
 * @author Holger Eichelberger, SSE
 */
public class MachineData {
    
    private int lotSize;
    private double powerConsumption;
    private String vendor; // usually would go into an own class/instance
    
    /**
     * Creates a machine data object.
     * 
     * @param lotSize the lot size
     * @param powerConsumption the power consumption
     * @param vendor the vendor name
     */
    public MachineData(int lotSize, double powerConsumption, String vendor) {
        this.lotSize = lotSize;
        this.powerConsumption = powerConsumption;
        this.vendor = vendor;
    }

    /**
     * Returns the actual lot size.
     * 
     * @return the actual lot size
     */
    public int getLotSize() {
        return lotSize;
    }

    /**
     * Returns the power consumption.
     * 
     * @return the actual power consumption
     */
    public double getPowerConsumption() {
        return powerConsumption;
    }

    /**
     * Returns the machine vendor name.
     * 
     * @return the vendor name
     */
    public String getVendor() {
        return vendor;
    }
}

==> connectors-0.7.1-20251117.164531-193-test-sources.jar: test/de/iip_ecosphere/platform/connectors/MachineData.java <==
/**
 * ******************************************************************************
 * Copyright (c) {2020} The original author or authors
 *
 * All rights reserved. This program and the accompanying materials are made 
 * available under the terms of the Eclipse Public License 2.0 which is available 
 * at http://www.eclipse.org/legal/epl-2.0, or the Apache License, Version 2.0
 * which is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * SPDX-License-Identifier: Apache-2.0 OR EPL-2.0
 ********************************************************************************/

package test.de.iip_ecosphere.platform.connectors;

/**
 * Test class representing machine data from the information model.
 * 
 * @author Holger Eichelberger, SSE
 */
public class MachineData {
    
    private int lotSize;
    private double powerConsumption;
    private String vendor; // usually would go into an own class/instance
    
    /**
     * Creates a machine data object.
     * 
     * @param lotSize the lot size
     * @param powerConsumption the power consumption
     * @param vendor the vendor name
     */
    public MachineData(int lotSize, double powerConsumption, String vendor) {
        this.lotSize = lotSize;
        this.powerConsumption = powerConsumption;
        this.vendor = vendor;
    }

    /**
     * Returns the actual lot size.
     * 
     * @return the actual lot size
     */
    public int getLotSize() {
        return lotSize;
    }

    /**
     * Returns the power consumption.
     * 
     * @return the actual power consumption
     */
    public double getPowerConsumption() {
        return powerConsumption;
    }

    /**
     * Returns the machine vendor name.
     * 
     * @return the vendor name
     */
    public String getVendor() {
        return vendor;
    }
    
    @Override
    public boolean equals(Object object) {
        boolean result = false;
        if (object instanceof MachineData) {
            MachineData d = (MachineData) object;
            result = getLotSize() == d.getLotSize() && vendor.equals(d.getVendor());
        }
        return result;
    }
    
    @Override
    public int hashCode() {
        return vendor.hashCode() + Integer.hashCode(getLotSize());
    }
    
}
